@@ -1,22 +1,15 @@
-try:
-    # Python < 3
-    from itertools import ifilter as filter
-except ImportError:
-    pass
-
 from pygments import highlight
+from pygments.formatters import HtmlFormatter
 from pygments.lexers import (
+    ClassNotFound,
+    TextLexer,
     get_lexer_by_name,
     get_lexer_for_filename,
     guess_lexer,
-    ClassNotFound,
-    TextLexer,
 )
-from pygments.formatters import HtmlFormatter
 
 from klaus import markup
 
-
 CTAGS_SUPPORTED_LANGUAGES = (
     "Asm Awk Basic C C# C++ Cobol DosBatch Eiffel Erlang Fortran HTML Java "
     "JavaScript Lisp Lua Make Makefile MatLab OCaml PHP Pascal Perl Python "
@@ -24,7 +17,7 @@ CTAGS_SUPPORTED_LANGUAGES = (
     # Not supported by Pygments: Asp Ant BETA Flex SLang Vera YACC
 ).split()
 PYGMENTS_CTAGS_LANGUAGE_MAP = dict(
-    (get_lexer_by_name(l).name, l) for l in CTAGS_SUPPORTED_LANGUAGES
+    (get_lexer_by_name(lexer).name, lexer) for lexer in CTAGS_SUPPORTED_LANGUAGES  # type: ignore
 )
 
 
@@ -36,7 +29,7 @@ class KlausDefaultFormatter(HtmlFormatter):
             lineanchors="L",
             linespans="L",
             anchorlinenos=True,
-            **kwargs
+            **kwargs,
         )
         self.language = language
         if ctags:
@@ -93,7 +86,7 @@ class KlausPythonFormatter(KlausDefaultFormatter):
         # so that non-import matches are always preferred over import matches.
         return filter(
             lambda match: match["kind"] != b"i",
-            super(KlausPythonFormatter, self).get_best_ctags_matches(matches),
+            super().get_best_ctags_matches(matches),
         )
 
 
