@@ -1,27 +1,32 @@
 import os
+from typing import Callable, List, Optional, Tuple
 
-LANGUAGES = []
+LANGUAGES: List[Tuple[List[str], Callable[[str], str]]] = []
 
 
-def get_renderer(filename):
+def get_renderer(filename: str) -> Optional[Callable[[str], str]]:
     _, ext = os.path.splitext(filename)
     for extensions, renderer in LANGUAGES:
         if ext in extensions:
             return renderer
+    return None
 
 
 def can_render(filename):
     return get_renderer(filename) is not None
 
 
-def render(filename, content=None):
+def render(filename, content=None) -> str:
     if content is None:
-        content = open(filename).read()
+        with open(filename) as f:
+            content = f.read()
 
-    return get_renderer(filename)(content)
+    renderer = get_renderer(filename)
+    assert renderer is not None, f"No renderer for {filename}"
+    return renderer(content)
 
 
-def _load_markdown():
+def _load_markdown() -> None:
     try:
         import markdown
     except ImportError:
@@ -33,7 +38,7 @@ def _load_markdown():
     LANGUAGES.append(([".md", ".mkdn", ".mdwn", ".markdown"], render_markdown))
 
 
-def _load_restructured_text():
+def _load_restructured_text() -> None:
     try:
         from docutils.core import publish_parts
         from docutils.writers.html4css1 import Writer
