@@ -1,17 +1,13 @@
 import sys
 import unittest
-
-try:
-    from unittest import mock
-except ImportError:
-    import mock
+from unittest import mock
 
 from klaus import utils
 
 
 class ForceUnicodeTests(unittest.TestCase):
     def test_ascii(self):
-        self.assertEqual(u"foo", utils.force_unicode(b"foo"))
+        self.assertEqual("foo", utils.force_unicode(b"foo"))
 
     def test_utf8(self):
         if sys.version_info[0] < 3:
@@ -37,5 +33,5 @@ class TarballBasenameTests(unittest.TestCase):
             ),
             ("vanilla", "klaus-vanilla"),
         ]
-        for (rev, basename) in examples:
+        for rev, basename in examples:
             self.assertEqual(utils.tarball_basename("klaus", rev), basename)
